@@ -67,7 +67,7 @@ def main():
     output_str = '\n'.join(f"{k}: {v}" for k, v in {
         k: {x: {y + f'({z})' * (y != '__init__'): a} for x, b in v.items() for y, z, a in [(k, x, b)] if x == 'classes'}
         for k, v in output.items() if v}.items())
-    print(output_str)
+    print(output)
 
 
 if __name__ == '__main__':
